@@ -30,13 +30,13 @@ fn display_help(programe_name:String) {
     println!("Usage:");
     println!("{} -f input file [-b][-c config file][-e][-F format][-g input file][-G #][-h]\
     [-H height][-i][-I][-J][-l factor][-L][-m][-o output file][-O][-p][-r ratio][-s][-S]\
-    [-t threshold][-t #][-v][-W width]",programe_name);
+    [-t threshold][-T #][-u threshold][-U #][-v][-W width]",programe_name);
     println!("    -b : open svg in browser");
     println!("    -c configfile: use a configuration file");
     println!("    -e : the node associated to FREE_LIVING are drawned in an \
     external tree (free_living option)");
     println!("    -F phylo/recphylo: force format phyloXML/recPhyloXML");
-    println!("    -g 2nd level input file");
+    println!("    -g 2nd level input file (for example a gene-symbiote file with -f defining a symbiote-host file)");
     println!("    -G <n> : display the gene #n in phyloxml style (no species tree)");
     println!("    -h : help");
     println!("    -H height : multiply the tree height by factor 'height' (default 1.0)");
@@ -55,16 +55,19 @@ fn display_help(programe_name:String) {
     println!("    -s : drawing species tree only");
     println!("    -S : display node support");
     println!("    -t <t> : redudant transfers are displayed as one, with opacity according \
-    to abundance and only if abundance is higher tan t. Only one gene is displayed.");
-    println!("    -T <n> : with option -t, select the gene to display");
+    to abundance and only if abundance is higher tan t.\n             Only one gene is displayed.");
+    println!("    -T <n> : with option -t, select the gene to display.");
+    println!("    -u <t> : with -g, same as -t, but apply to the '-f' input file, and -t will apply to the '-g' file.");
+    println!("    -U <n> : same as -T with -t, but for -u");
     println!("    -v : verbose");
     println!("    -W width : multiply the tree width by factor 'width' (default 1.0)");
     println!("");
     println!("    Note on -b option : you must set a browser as default application for opening \
     svg file");
     println!("");
-    println!("    Note on -g option : this will generate 3-levels reconciliation svg.");
+    println!("    Note on -g option : this will generate 3-levels reconciliation svg files.");
     println!("    For example you may input a gene-symbiote recphyloxml file  with -g and symbiote-host recphyloxml file with -f");
+    println!("    The -t/-g options are not totally implemented for the mapped_1/2/3 svg output files.");
     println!("");
     println!("Input format is guessed according to the file name extension:");
 
@@ -116,7 +119,7 @@ fn main()  {
     if args.len() == 1 {
          display_help(args[0].to_string());
     }
-    let mut opts = getopt::Parser::new(&args, "c:bef:F:g:G:hH:iIJl:Lmo:Opr:sSt:T:vW:");
+    let mut opts = getopt::Parser::new(&args, "c:bef:F:g:G:hH:iIJl:Lmo:Opr:sSt:T:u:U:vW:");
     let mut infile_sh = String::new(); // symbiote host file
     let mut infile_gs = String::new(); // gene symbiote file
     let mut outfile = String::from("thirdkind.svg");
@@ -124,6 +127,14 @@ fn main()  {
     let mut level3 = false; // Affichage à 3 niveaux
     let mut multiple_files = false;
     let mut _format = Format::Newick;
+    // 1st level file option
+    let mut thickness_thresh_1st = 0;
+    let mut thickness_gene_1st = 1;
+    let mut thickness_flag_1st = false;
+    // 2nd level file option
+    let mut thickness_thresh_2nd = 0;
+    let mut thickness_gene_2nd = 1;
+    let mut thickness_flag_2nd = false;
     loop {
         match opts.next().transpose() {
             Err(err) => {
@@ -184,17 +195,17 @@ fn main()  {
                     Opt('s', None) => options.species_only_flag = true,
                     Opt('S', None) => options.support = true,
                     Opt('t', Some(string)) => {
-                        options.thickness_thresh = match string.parse::<usize>(){
+                        thickness_thresh_1st = match string.parse::<usize>(){
                             Ok(valeur) => valeur,
                             Err(_err) => {
                                 eprintln!("Error! Please give a integer value with -t option");
                                 process::exit(1);
                             },
                         };
-                        options.thickness_flag = true;
+                        thickness_flag_1st = true;
                     },
                     Opt('T', Some(string)) => {
-                        options.thickness_gene = match string.parse::<usize>(){
+                        thickness_gene_1st = match string.parse::<usize>(){
                             Ok(valeur) => valeur,
                             Err(_err) => {
                                 eprintln!("Error! Please give a integer value with -T option");
@@ -202,6 +213,25 @@ fn main()  {
                             },
                         };
                     },
+                    Opt('u', Some(string)) => {
+                        thickness_thresh_2nd = match string.parse::<usize>(){
+                            Ok(valeur) => valeur,
+                            Err(_err) => {
+                                eprintln!("Error! Please give a integer value with -u option");
+                                process::exit(1);
+                            },
+                        };
+                        thickness_flag_2nd = true;
+                    },
+                    Opt('U', Some(string)) => {
+                        thickness_gene_2nd = match string.parse::<usize>(){
+                            Ok(valeur) => valeur,
+                            Err(_err) => {
+                                eprintln!("Error! Please give a integer value with -U option");
+                                process::exit(1);
+                            },
+                        };
+                    },
                     Opt('l', Some(string)) => {
                         options.real_length_flag = true;
                         options.scale = match string.parse::<f32>(){
@@ -247,6 +277,14 @@ fn main()  {
          display_help(args[0].to_string());
     }
 
+    // Setting options on thickness
+    options.thickness_flag = thickness_flag_1st;
+    options.thickness_gene = thickness_gene_1st;
+    options.thickness_thresh = thickness_thresh_1st;
+
+// ================================================================================================
+//          RECONCILIATION A 3 NIVEAUX
+// ================================================================================================
     if level3 {
         // Traitement de 2 fichier fichiers recPhyloXML
         println!("Two reconciled files => displaying 3-levels reconciliations. ");
@@ -255,213 +293,387 @@ fn main()  {
         let  outfile_mapped_1 = String::from("thirdkind_mapped_1.svg");
         let  outfile_mapped_2 = String::from("thirdkind_mapped_2.svg");
         let  outfile_mapped_3 = String::from("thirdkind_mapped_3.svg");
-
         let transfers = vec![]; // Initialise transfers
-// ---------------------------------------------------------
-// Create a structure Arena for the global parasite pipe
-// tree and a vector of structures Arena for gene path trees
-// ---------------------------------------------------------
-let mut global_pipe_parasite: ArenaTree<String> = ArenaTree::default();
-let mut global_roots: std::vec::Vec<usize> = Vec::new();
-let mut path_genes: std::vec::Vec<ArenaTree<String>> = Vec::new();
-// ---------------------------------------------------------
-// Fill global parasite pipe tree and is roots and path
-// genes trees
-// ---------------------------------------------------------
-read_recphyloxml_multi(infile_gs,&mut global_pipe_parasite,&mut path_genes,&mut global_roots);
-let  nb_gntree =  path_genes.len().clone();
-println!("Number of gene trees : {}",nb_gntree);
-info!("List of gene trees : {:?}",path_genes);
-let  nb_parasite_pipe =  global_roots.len().clone();
-println!("Number of symbiote trees : {}",nb_parasite_pipe);
-println!("List of species trees roots : {:?}",global_roots);
-info!("Global symbiote pipe tree : {:?}",global_pipe_parasite);
-println!();
-println!("Building svg 1: reconciled pipe symbiote tree(s) with gene tree(s) [{}]",
-    outfile_mapped_1);
-// ---------------------------------------------------------
-// Generate svg of the lobal parasite pipe tree and  path
-// genes trees
-// ---------------------------------------------------------
-recphyloxml_processing(&mut global_pipe_parasite,&mut  path_genes, &mut options, &config,true,
-        &transfers,outfile_gene_para);
-// ---------------------------------------------------------
-// Create a structure Arena for the host pipe tree and a
-// vector of structures Arena for parasite path trees
-// ---------------------------------------------------------
-let mut tree_host_pipe: ArenaTree<String> = ArenaTree::default();
-let mut path_para_trees:std::vec::Vec<ArenaTree<String>> = Vec::new();
-// ---------------------------------------------------------
-// Fill  host pipe tree and is roots and path parasite trees
-// ---------------------------------------------------------
-let mut global_roots: std::vec::Vec<usize> = Vec::new();
-read_recphyloxml_multi(infile_sh,&mut tree_host_pipe,&mut path_para_trees, &mut global_roots);
-let  nb_parasite_path =  path_para_trees.len().clone();
-println!("Number of pipe symbiote trees in gene-symbiote file : {}",nb_parasite_pipe);
-println!("Number of path symbiote trees in symbiote-host file : {}",nb_parasite_path);
-if nb_parasite_path != nb_parasite_pipe {
-    println!();
-    println!("==============================================");
-    println!("Error! Different number of parasite trees in the 2 files!");
-    println!("       Resulting svg will be incomplete.");
-    println!("==============================================");
-    println!();
-}
-// ---------------------------------------------------------
-// Generate svg of the host pipe tree and path symbiote trees
-// ---------------------------------------------------------
-recphyloxml_processing(&mut tree_host_pipe,&mut  path_para_trees, &mut options, &config,
-    true, &transfers,outfile_para_host);
-// ---------------------------------------------------------
-// Generation of first 3 levels svg
-// ---------------------------------------------------------
-info!("Symbiote trees as a 'path tree' : {:?}",path_para_trees);
-info!("Symbiote tree as a 'pipe tree' : {:?}",global_pipe_parasite);
-println!("==============================================");
-println!("Map symbiote as 'path' to symbiote as 'pipe'");
-println!("==============================================");
-let mut i = 0;
-while i < nb_parasite_pipe {
-        map_parasite_g2s(&mut global_pipe_parasite, &mut path_para_trees[i]);
-i = i + 1;
-}
-info!("Global symbiote tree wih events : {:?}",global_pipe_parasite);
-reset_pos(&mut global_pipe_parasite);
-let mut i = 0;
-while i < nb_gntree {
-    reset_pos(&mut path_genes[i]);
-    i = i + 1;
-}
-println!("==============================================");
-println!("Map symbiote as 'pipe' to symbiote as 'path'");
-println!("==============================================");
-let mut i = 0;
-while i < nb_parasite_pipe {
-    map_parasite_s2g(&mut global_pipe_parasite, &mut path_para_trees[i],&mut path_genes);
-    i = i +  1;
-}
-info!("Global pipe symbiote after mapping s2g : {:?}",global_pipe_parasite);
-println!("==============================================");
-println!("Map symbiote as 'path' to symbiote as 'pipe' again");
-println!("==============================================");
-let mut i = 0;
-while i < nb_parasite_pipe {
-    map_parasite_g2s(&mut global_pipe_parasite, &mut path_para_trees[i]);
-    i = i + 1;
-}
-reset_pos(&mut global_pipe_parasite);
-let mut i = 0;
-while i < nb_gntree {
-    reset_pos(&mut path_genes[i]);
-    i = i + 1;
-}
-// attention on ne remape pas
-recphyloxml_processing(&mut global_pipe_parasite,&mut  path_genes, &mut options, &config,false,
-        &transfers,outfile_mapped_1);
-let path = env::current_dir().expect("Unable to get current dir");
-let url_file = format!("file:///{}/{}", path.display(),"thirdkind_mapped_1.svg".to_string());
-if options.open_browser {
-    if webbrowser::open_browser(Browser::Default,&url_file).is_ok() {
-            info!("Browser OK");
+        let mut transfers_gene = vec![]; // Transferts de genes
+        let mut transfers_para = vec![]; // Transferts de parasites(ou symbiotes)
+
+        //
+        // GENE - PARASITE STUFF
+        //
+        // ---------------------------------------------------------
+        // Create a structure Arena for the global parasite pipe
+        // tree and a vector of structures Arena for gene path trees
+        // ---------------------------------------------------------
+        let mut global_pipe_parasite: ArenaTree<String> = ArenaTree::default();
+        let mut global_roots: std::vec::Vec<usize> = Vec::new();
+        let mut path_genes: std::vec::Vec<ArenaTree<String>> = Vec::new();
+
+        // ---------------------------------------------------------
+        // Fill global parasite pipe tree and is roots and path
+        // genes trees
+        // ---------------------------------------------------------
+        read_recphyloxml_multi(infile_gs,&mut global_pipe_parasite,&mut path_genes,&mut global_roots);
+        let  nb_gntree =  path_genes.len().clone();
+        println!("Number of gene trees : {}",nb_gntree);
+        info!("List of gene trees : {:?}",path_genes);
+        let  nb_parasite_pipe =  global_roots.len().clone();
+        println!("Number of symbiote trees : {}",nb_parasite_pipe);
+        println!("List of species trees roots : {:?}",global_roots);
+        info!("Global symbiote pipe tree : {:?}",global_pipe_parasite);
+        println!();
+
+        // ---------------------------------------------------------
+        // Generate svg of the global parasite pipe tree and  path
+        // genes trees (outfile_gene_para)
+        // ---------------------------------------------------------
+
+        // If  the option -t is on :
+        if thickness_flag_1st {
+            // check that gene nb is correct
+            if thickness_gene_1st > nb_gntree {
+                println!("There are only {} genes in the file, unable to display gene #{}",
+                nb_gntree,thickness_gene_1st);
+                process::exit(1);
+            }
+
+            //  Get the transfers in the genes
+            transfers_gene = get_gtransfer(&mut path_genes[0]);
+            let mut i = 1;
+            while i < nb_gntree {
+                let gene_transfer = get_gtransfer(&mut path_genes[i]);
+                for val in gene_transfer {
+                    transfers_gene.push(val);
+                }
+                i = i + 1;
+            }
+            println!("Transfers (genes) = {:?}",transfers_gene);
+            // Define the unique gene wich is selected
+            let mut selected_gene_trees:std::vec::Vec<ArenaTree<String>> = Vec::new();
+            selected_gene_trees.push(path_genes[thickness_gene_1st-1].copie());
+
+            // Define a temporary copy of the species tree
+            let mut _global_pipe_parasite = global_pipe_parasite.copie();
+            // Set options
+            options.thickness_flag = true;
+            options.thickness_gene = thickness_gene_1st;
+            options.thickness_thresh = thickness_thresh_1st;
+            //  Create the svg from temporary variables
+            recphyloxml_processing(&mut _global_pipe_parasite, &mut selected_gene_trees, &mut options,
+                &config, true, &transfers_gene, outfile_gene_para.clone());
+            // We need to run again with the current variables, because we need the upddated
+            // global_pipe_parasite path_genes
+            recphyloxml_processing(&mut global_pipe_parasite,&mut  path_genes, &mut options, &config,true,
+                &transfers,"tmpfile.svg".to_string());
+        }
+        // No -t option
+        else {
+            recphyloxml_processing(&mut global_pipe_parasite,&mut  path_genes, &mut options, &config,true,
+                &transfers,outfile_gene_para);
+        }
+
+        //
+        // PARASITE-HOST  STUFF
+        //
+        // ---------------------------------------------------------
+        // Create a structure Arena for the host pipe tree and a
+        // vector of structures Arena for parasite path trees
+        // ---------------------------------------------------------
+        let mut tree_host_pipe: ArenaTree<String> = ArenaTree::default();
+        let mut path_para_trees:std::vec::Vec<ArenaTree<String>> = Vec::new();
+        // ---------------------------------------------------------
+        // Fill  host pipe tree and is roots and path parasite trees
+        // ---------------------------------------------------------
+        let mut global_roots: std::vec::Vec<usize> = Vec::new();
+        read_recphyloxml_multi(infile_sh,&mut tree_host_pipe,&mut path_para_trees, &mut global_roots);
+        let  nb_parasite_path =  path_para_trees.len().clone();
+        println!("Number of pipe symbiote trees in gene-symbiote file : {}",nb_parasite_pipe);
+        println!("Number of path symbiote trees in symbiote-host file : {}",nb_parasite_path);
+        if nb_parasite_path != nb_parasite_pipe {
+            println!();
+            println!("==============================================");
+            println!("Error! Different number of parasite trees in the 2 files!");
+            println!("       Resulting svg will be incomplete.");
+            println!("==============================================");
+            println!();
+        }
+
+        // ---------------------------------------------------------
+        // Generate svg of the host pipe tree and path symbiote trees
+        // ---------------------------------------------------------
+
+        // Reset the option
+        options.thickness_flag = false;
+
+        // If  the option -u is on :
+        if thickness_flag_2nd {
+            options.thickness_flag = true;
+            options.thickness_gene = thickness_gene_2nd;
+            options.thickness_thresh = thickness_thresh_2nd;
+
+            // check that the number pf the parasite is correct
+            if options.thickness_gene > nb_parasite_path {
+                println!("There are only {} parasites in the file, unable to display gene #{}",
+                nb_parasite_path,options.thickness_gene);
+                process::exit(1);
+            }
+
+            // Get teh transfers in the parasites
+            transfers_para = get_gtransfer(&mut path_para_trees[0]);
+            let mut i = 1;
+            while i < nb_parasite_path {
+                let gene_transfer = get_gtransfer(&mut path_para_trees[i]);
+                for val in gene_transfer {
+                    transfers_para.push(val);
+                }
+            i = i + 1;
+            }
+            println!("Transfers (parasites) = {:?}",transfers_para);
+            // Define a temporary copy of the paraistes
+            let mut _path_para_trees: std::vec::Vec<ArenaTree<String>> = Vec::new();
+            for i in 0 .. path_para_trees.len() {
+                _path_para_trees.push(path_para_trees[i].copie());
+            }
+            // Define the unique parasite  wich is selected
+            let mut selected_para_trees:std::vec::Vec<ArenaTree<String>> = Vec::new();
+            selected_para_trees.push(_path_para_trees.remove(options.thickness_gene-1));
+            // Define a tmprary copy of the host
+            let mut _tree_host_pipe = tree_host_pipe.copie();
+
+            //  Create the svg from the temprary variables
+            recphyloxml_processing(&mut _tree_host_pipe, &mut selected_para_trees, &mut options,
+            &config, true, &transfers_para, outfile_para_host.clone());
+            // We need to run again with the current variables, because we need the upddated
+            // _tree_host_pipe path_para_trees
+            recphyloxml_processing(&mut tree_host_pipe,&mut  path_para_trees, &mut options,
+                 &config,true, &transfers,"tmpfile2.svg".to_string());
+
+        }
+        // No -u option
+        else {
+            recphyloxml_processing(&mut tree_host_pipe,&mut  path_para_trees, &mut options,
+                &config, true, &transfers,outfile_para_host);
+        }
+
+        //
+        // GENE-PARASITE-HOST  STUFF : MAP1
+        //
+        // ---------------------------------------------------------
+        // Generation of first 3 levels svg
+        // ---------------------------------------------------------
+        println!("Building svg 1: reconciled pipe symbiote tree(s) with gene tree(s) [{}]",
+            outfile_mapped_1);
+        info!("Symbiote trees as a 'path tree' : {:?}",path_para_trees);
+        info!("Symbiote tree as a 'pipe tree' : {:?}",global_pipe_parasite);
+        println!("==============================================");
+        println!("Map symbiote as 'path' to symbiote as 'pipe'");
+        println!("==============================================");
+        let mut i = 0;
+        while i < nb_parasite_pipe {
+            map_parasite_g2s(&mut global_pipe_parasite, &mut path_para_trees[i]);
+            i = i + 1;
+        }
+        info!("Global symbiote tree wih events : {:?}",global_pipe_parasite);
+        reset_pos(&mut global_pipe_parasite);
+        let mut i = 0;
+        while i < nb_gntree {
+            reset_pos(&mut path_genes[i]);
+            i = i + 1;
+        }
+
+        //  We need to handel the -t option
+        //  C'est complexe il faut eliminer les noeuds associer aux genes qui ne sont pas selectionnes
+        //  A developper
+        // let mut _path_genes: std::vec::Vec<ArenaTree<String>> = Vec::new();
+        // let mut selected_gene_trees:std::vec::Vec<ArenaTree<String>> = Vec::new();
+        // let mut _global_pipe_parasite: ArenaTree<String> = ArenaTree::default();
+        // if thickness_flag_1st {
+        //     for i in 0 .. path_genes.len() {
+        //         _path_genes.push(path_genes[i].copie());
+        //     }
+        // // Define the unique gene wich is selected
+        // selected_gene_trees.push(_path_genes.remove(thickness_gene_1st-1));
+        // // Define a temporary copy of the species tree
+        // _global_pipe_parasite = global_pipe_parasite.copie();
+        // }
+
+        println!("==============================================");
+        println!("Map symbiote as 'pipe' to symbiote as 'path'");
+        println!("==============================================");
+        // if thickness_flag_1st {
+        //     let mut i = 0;
+        //     while i < nb_parasite_pipe {
+        //         map_parasite_s2g(&mut _global_pipe_parasite, &mut path_para_trees[i], &mut selected_gene_trees);
+        //         i = i +  1;
+        //     }
+        // }
+        // else {
+        let mut i = 0;
+        while i < nb_parasite_pipe {
+            map_parasite_s2g(&mut global_pipe_parasite, &mut path_para_trees[i],&mut path_genes);
+            i = i +  1;
+        }
+        // }
+        info!("Global pipe symbiote after mapping s2g : {:?}",global_pipe_parasite);
+        println!("==============================================");
+        println!("Map symbiote as 'path' to symbiote as 'pipe' again");
+        println!("==============================================");
+        let mut i = 0;
+        while i < nb_parasite_pipe {
+            map_parasite_g2s(&mut global_pipe_parasite, &mut path_para_trees[i]);
+            i = i + 1;
+        }
+        reset_pos(&mut global_pipe_parasite);
+        let mut i = 0;
+        while i < nb_gntree {
+            reset_pos(&mut path_genes[i]);
+            i = i + 1;
+        }
+        // if thickness_flag_1st {
+        // reset_pos(&mut selected_gene_trees[0]);
+        // }
+
+        // Reset the option
+        options.thickness_flag = false;
+        //  option -t is on
+        if thickness_flag_1st {
+            options.thickness_flag = true;
+            options.thickness_gene = thickness_gene_1st;
+            options.thickness_thresh = thickness_thresh_1st;
+        }
+        // attention on ne remape pas
+        recphyloxml_processing(&mut global_pipe_parasite,&mut  path_genes, &mut options, &config,false,
+            &transfers_gene,outfile_mapped_1);
+        let path = env::current_dir().expect("Unable to get current dir");
+        let url_file = format!("file:///{}/{}", path.display(),"thirdkind_mapped_1.svg".to_string());
+        if options.open_browser {
+            if webbrowser::open_browser(Browser::Default,&url_file).is_ok() {
+                info!("Browser OK");
+            }
+        }
+
+        //
+        // GENE-PARASITE-HOST  STUFF : MAP2
+        //
+        // ---------------------------------------------------------
+        // Generation of second 3 levels svg
+        // ---------------------------------------------------------
+        println!();
+        println!("Building svg 2:  symbiote tree(s) within host pipe tree and mapped gene transfers [{}]",
+            outfile_mapped_2);
+        let mut i = 0;
+        // We get the gene transfer here again, but they will be mapped
+        let gene_transfers = get_gtransfer(&mut path_genes[i]);
+        info!("Transfers = {:?}",gene_transfers);
+        let mut mapped_gene_transfers = map_transfer_mul(gene_transfers, &mut path_para_trees);
+        info!("Mapped transfers = {:?}",mapped_gene_transfers);
+        i = i + 1;
+        while i < nb_gntree {
+            let gene_transfers = get_gtransfer(&mut path_genes[i]);
+            info!("Transfers = {:?}",gene_transfers);
+            let mapped = map_transfer_mul(gene_transfers, &mut path_para_trees);
+            info!("Mapped transfers = {:?}",mapped);
+            for val in mapped {
+                mapped_gene_transfers.push(val);
+            }
+            i = i + 1;
+        }
+        info!("Mapped transfers = {:?}",mapped_gene_transfers);
+        // Reseting the pipe and the paths
+        reset_pos(&mut tree_host_pipe);
+        let mut i = 0;
+        while i < nb_parasite_pipe {
+            reset_pos(&mut path_para_trees[i]);
+            i = i + 1;
+        }
+        // Setting option to false because we dont want the parasite transerst to be hidden
+        options.thickness_flag = false;
+
+        if thickness_flag_2nd {
+            // On ajoute les transferts de paraistes au transferts de gene
+            options.thickness_flag = true;
+            options.thickness_gene = thickness_gene_2nd;
+            options.thickness_thresh = thickness_thresh_2nd;
+            //  Create the svg from temporary variables
+            for val in transfers_para {
+                mapped_gene_transfers.push(val);
+            }
+        }
+
+        // attention on ne remape pas
+        recphyloxml_processing(&mut tree_host_pipe, &mut path_para_trees, &mut options, &config,
+            false, &mapped_gene_transfers,outfile_mapped_2);
+        let path = env::current_dir().expect("Unable to get current dir");
+        let url_file = format!("file:///{}/{}", path.display(),"thirdkind_mapped_2.svg".to_string());
+        if options.open_browser {
+            if webbrowser::open_browser(Browser::Default,&url_file).is_ok() {
+                info!("Browser OK");
+            }
+        }
+        //  Simple tree of the parasite
+        reset_pos(&mut global_pipe_parasite);
+        phyloxml_processing(&mut global_pipe_parasite, &mut options, &config,"thirdkind_para_simple.svg".to_string());
+        reset_pos(&mut tree_host_pipe);
+        //  Simple tree of the host
+        phyloxml_processing(&mut tree_host_pipe, &mut options, &config,"thirdkind_host_simple.svg".to_string());
+        //  Simple trees of the genes
+        let mut i = 0;
+        while i < nb_parasite_pipe {
+            reset_pos(&mut path_para_trees[i]);
+            phyloxml_processing(&mut path_para_trees[i], &mut options, &config,("thirdkind_gene_simple_".to_owned()+&i.to_string()+".svg").to_string());
+            i = i + 1;
+        }
+
+        //
+        // GENE-PARASITE-HOST  STUFF : MAP3
+        //
+        // ---------------------------------------------------------
+        // Generation of third 3 levels svg UNDER DEVELOPMENT
+        // --------------------------------------------------------
+        println!();
+        println!("Building svg 3: pipe host tree with gene tree(s) inside [{}]",outfile_mapped_3);
+        map_gene_host(&mut path_genes, &mut path_para_trees, &mut tree_host_pipe);
+        reset_pos(&mut tree_host_pipe);
+        let mut i = 0;
+        while i < nb_gntree {
+            reset_pos(&mut path_genes[i]);
+            i = i + 1;
+        }
+        recphyloxml_processing(&mut tree_host_pipe, &mut path_genes, &mut options, &config,
+            true, &vec![],outfile_mapped_3);
+        let url_file = format!("file:///{}/{}", path.display(),"thirdkind_mapped_3.svg".to_string());
+        if options.open_browser {
+            if webbrowser::open_browser(Browser::Default,&url_file).is_ok() {
+                info!("Browser OK");
+            }
+        }
+        println!("Output files:");
+        println!(" - thirdkind_host_simple.svg ...... 1 level:  host tree");
+        let mut i = 0;
+        while i < nb_parasite_pipe {
+            println!(" - thirdkind_gene_simple_{}.svg .... 2 levels: gene tree(s)",&i);
+            i = i + 1;
+        }
+        println!(" - thirdkind_symbiote_simple.svg .. 2 levels: symbiote tree(s)");
+        println!(" - thirdkind_gene_para.svg ........ 2 levels: pipe symbiote tree(s) with gene tree(s) inside");
+        println!(" - thirdkind_symbiote_host.svg .... 2 levels: pipe host tree with symbiote tree(s) inside");
+        println!(" - thirdkind_mapped_1.svg ........  3 levels: reconciled pipe symbiote tree(s) with gene tree(s)");
+        println!(" - thirdkind_mapped_2.svg ........  3 levels: symbiote-host reconciliation plus gene transfers");
+        println!(" - thirdkind_mapped_3.svg ........  3 levels: pipe host tree with gene tree(s) inside");
+
+        if nb_parasite_path != nb_parasite_pipe {
+            println!();
+            println!("==============================================");
+            println!("Error! Different number of symbiote trees in the 2 files!");
+            println!("       Resulting svg will be incomplete.");
+            println!("==============================================");
+            println!();
         }
     }
 
-// ---------------------------------------------------------
-// Generation of second 3 levels svg
-// ---------------------------------------------------------
-println!();
-println!("Building svg 2:  symbiote tree(s) within host pipe tree and mapped gene transfers [{}]",
-    outfile_mapped_2);
-let mut i = 0;
-let gene_transfers = get_gtransfer(&mut path_genes[i]);
-info!("Transfers = {:?}",gene_transfers);
-let mut mapped_gene_transfers = map_transfer_mul(gene_transfers, &mut path_para_trees);
-info!("Mapped transfers = {:?}",mapped_gene_transfers);
-i = i + 1;
-while i < nb_gntree {
-    let gene_transfers = get_gtransfer(&mut path_genes[i]);
-    info!("Transfers = {:?}",gene_transfers);
-    let mapped = map_transfer(gene_transfers, &mut path_para_trees[0]);
-    info!("Mapped transfers = {:?}",mapped);
-    for val in mapped {
-        mapped_gene_transfers.push(val);
-    }
-    i = i + 1;
-}
-reset_pos(&mut tree_host_pipe);
-let mut i = 0;
-while i < nb_parasite_pipe {
-    reset_pos(&mut path_para_trees[i]);
-    i = i + 1;
-}
-// attention on ne remape pas
-recphyloxml_processing(&mut tree_host_pipe, &mut path_para_trees, &mut options, &config,
-    false, &mapped_gene_transfers,outfile_mapped_2);
-let path = env::current_dir().expect("Unable to get current dir");
-let url_file = format!("file:///{}/{}", path.display(),"thirdkind_mapped_2.svg".to_string());
-if options.open_browser {
-    if webbrowser::open_browser(Browser::Default,&url_file).is_ok() {
-        info!("Browser OK");
-    }
-}
+    // =================================
+    //  RECONCILIATION A 2 DEUX NIVEAUX
+    // =================================
 
-reset_pos(&mut global_pipe_parasite);
-phyloxml_processing(&mut global_pipe_parasite, &mut options, &config,"thirdkind_para_simple.svg".to_string());
-reset_pos(&mut tree_host_pipe);
-phyloxml_processing(&mut tree_host_pipe, &mut options, &config,"thirdkind_host_simple.svg".to_string());
-let mut i = 0;
-while i < nb_parasite_pipe {
-    reset_pos(&mut path_para_trees[i]);
-    phyloxml_processing(&mut path_para_trees[i], &mut options, &config,("thirdkind_gene_simple_".to_owned()+&i.to_string()+".svg").to_string());
-    i = i + 1;
-}
-
-// ---------------------------------------------------------
-// Generation of third 3 levels svg UNDER DEVELOPMENT
-// --------------------------------------------------------
-println!();
-println!("Building svg 3: pipe host tree with gene tree(s) inside [{}]",
-    outfile_mapped_3);
-map_gene_host(&mut path_genes, &mut path_para_trees, &mut tree_host_pipe);
-reset_pos(&mut tree_host_pipe);
-let mut i = 0;
-while i < nb_gntree {
-    reset_pos(&mut path_genes[i]);
-    i = i + 1;
-}
-recphyloxml_processing(&mut tree_host_pipe, &mut path_genes, &mut options, &config,
-    true, &vec![],outfile_mapped_3);
-
-let url_file = format!("file:///{}/{}", path.display(),"thirdkind_mapped_3.svg".to_string());
-    if options.open_browser {
-        if webbrowser::open_browser(Browser::Default,&url_file).is_ok() {
-            info!("Browser OK");
-        }
-    }
-println!("Output files:");
-println!(" - thirdkind_host_simple.svg ...... 1 level:  host tree");
-let mut i = 0;
-while i < nb_parasite_pipe {
-    println!(" - thirdkind_gene_simple_{}.svg .... 2 levels: gene tree(s)",&i);
-    i = i + 1;
-}
-println!(" - thirdkind_symbiote_simple.svg .. 2 levels: symbiote tree(s)");
-println!(" - thirdkind_gene_para.svg ........ 2 levels: pipe symbiote tree(s) with gene tree(s) inside");
-println!(" - thirdkind_symbiote_host.svg .... 2 levels: pipe host tree with symbiote tree(s) inside");
-println!(" - thirdkind_mapped_1.svg ........  3 levels: reconciled pipe symbiote tree(s) with gene tree(s)");
-println!(" - thirdkind_mapped_2.svg ........  3 levels: symbiote-host reconciliation plus gene transfers");
-println!(" - thirdkind_mapped_3.svg ........  3 levels: pipe host tree with gene tree(s) inside");
-
-if nb_parasite_path != nb_parasite_pipe {
-    println!();
-    println!("==============================================");
-    println!("Error! Different number of symbiote trees in the 2 files!");
-    println!("       Resulting svg will be incomplete.");
-    println!("==============================================");
-    println!();
-}
-
-    }
     else if multiple_files {
         // get the url
         let path = env::current_dir().expect("Unable to get current dir");
@@ -521,7 +733,7 @@ if nb_parasite_path != nb_parasite_pipe {
             }
             info!("Transfers = {:?}",transfers);
             let mut selected_gene_trees:std::vec::Vec<ArenaTree<String>> = Vec::new();
-            selected_gene_trees.push(gene_trees.remove(options.thickness_gene));
+            selected_gene_trees.push(gene_trees.remove(options.thickness_gene-1));
             recphyloxml_processing(&mut sp_trees[0], &mut selected_gene_trees, &mut options,
                 &config, true, &transfers, outfile);
         }
@@ -636,7 +848,7 @@ if nb_parasite_path != nb_parasite_pipe {
                     }
                     info!("Transfers = {:?}",transfers);
                     let mut selected_gene_trees:std::vec::Vec<ArenaTree<String>> = Vec::new();
-                    selected_gene_trees.push(gene_trees.remove(options.thickness_gene));
+                    selected_gene_trees.push(gene_trees.remove(options.thickness_gene-1));
                     recphyloxml_processing(&mut sp_tree, &mut selected_gene_trees, &mut options,
                         &config, true, &transfers, outfile);
                     }
